Selenium starting points

# Selenium

Selenium TestRunner - Select a test suite to run in Selenium

Acceptance tests: These test-suites demonstrate/exercise the functionality of Selenium.

- Selenium TestSuite - functional tests for Selenium. This suite of tests should pass in any supported browser.
- Error Checking TestSuite - tests for the error verification commands
- Dogfood TestSuite - test Selenium with Selenium

Unit-tests: Use JsUnit to test Selenium internals.

- Selenium BrowserBot unit-tests
- Selenium TestRunner UI unit-tests
- JsMock unit-tests